Welcome to SplAdder's documentation!
====================================

Welcome to the documentation of SplAdder. Here you will learn more about the details of the SplAdder
pipeline, how to apply it to your data, how ^to choose parameters well suited for the kind of
question you would like to answer, or how to use and visualize the output data. SplAdder is
continuously improved and currently in alpha state. It has been used and tested in context of
various research projects of varying scale, ranging from a few samples of *A. thaliana* to thousands
of human samples.

To install the latest release, please use::

    pip install spladder

Further information about requirements can be found in the :ref:`Installation notes <installation>`.

Before diving deeper into the documentation, we suggest to read through the :ref:`General
information <general_info>` first.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   installation.rst
   general.rst
   spladder_modes.rst
   spladder_cohort.rst
   file_formats.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
